<!Doctype Html>  

<html>
    <body>
        <head>
    <script src="jquery-3.6.1.min.js"></script>
    <script src="sweetalert2.all.min.js"></script> 
</head>

<h1>

<?php

    if(isset($_SESSION['upload_status']))
    {
        ?>
        <script>
            swal({
                title: "<?php echo $_SESSION['upload_status']; ?>",
                text:  "File status",
                button: "ok ",
            }).then (function() {
                window.location.href = "tinyfilemanager.php";
            });
        </script>
        <?php
            unset($_SESSION['upload_status']);
    }

?>
</h1>

</body>
</html>
