@CHARSET "ISO-8859-1";
.fileContainer { width:100%; }

label { 
    font-weight:bold;
    font-size:120%;
    text-align:justify;
    padding:10px;
    margin: 10px;
}

.button {
  border: none;
  color: black;
  padding: 1px;
  text-align: right;
  text-decoration: none;
  display: inline-block;
  font-size: 18px;
  margin: 4px 2px;
  cursor: pointer;
}

.button1 {
  border: none;
  color: black;
  padding: 1px;
  text-align: right;
  text-decoration: none;
  display: inline-block;
  font-size: 18px;
  margin: 12px 320px;
  cursor: pointer;
}