@CHARSET "ISO-8859-1";
.fileContainer { width:100%; }

.file {
	border:1px solid #000;
	padding:0px;
	width:550px;
}

.file thead tr {
	background:transparent url("../images/tablebg.jpg");
	color:#FFF;
	font-size:110%;
	font-weight:bold;
}

.file thead td {
	border-bottom:1px solid #000;
	height:25px;
	padding:0 5px 0 5px;
}

.file tbody tr:hover { background-color:#ffb2b2; }

.file tbody td { padding:3px; text-indent:2px; }

.file tfoot { 
	background-color:#662222;
	color:white;
	font-weight:bold;
	font-size:100%;
	text-align:center;
}
.file tfoot td { padding:2px; border-top:1px solid #000; }

.odd { background-color:#ffeded; }

.even { background-color:#ffffff; }

.path {
	padding:3px;
	background-color:#FFEDED;
	border:1px solid #000;
	width:550px;
}

fieldset { 
	border: 1px solid #252424;
	border-radius: 6px;
}



