#!/bin/sh
echo "u417.sh" >> /tmp/u417.txt
date >> /tmp/u417.txt
whoami >> /tmp/u417.txt

cp -p -f $UPD825/card/batcher /usr/sbin/card
cp -p -f $UPD825/card/chkwgh /usr/sbin/card
cp -p -f $UPD825/card/hway /usr/sbin/card
cp -p -f $UPD825/card/ids /usr/sbin/card
cp -p -f $UPD825/card/mscale /usr/sbin/card

if [ ! -d "/usr/sbin/card/vrs" ]; then
    mkdir /usr/sbin/card/vrs
fi
install -m 0755 -o root -g root $UPD825/card/vrs/vrs /usr/sbin/card/vrs
install -m 0644 -o root -g root $UPD825/card/vrs/vrs.pdf /usr/sbin/card/vrs

if [ ! -d "/usr/sbin/card/cbw" ]; then
    mkdir /usr/sbin/card/cbw
fi
cp -p -f $UPD825/card/cbw/cbw /usr/sbin/card/cbw

cp -p -f $UPD825/diag/setup /usr/sbin/diag
cp -p -f $UPD825/diag/config /usr/sbin/diag
cp -p -f $UPD825/diag/filemanage /usr/sbin/diag
cp -p -f $UPD825/diag/appmenu /usr/sbin/diag
cp -p -f $UPD825/diag/appmenu.sh /usr/sbin/diag

if [ ! -d "/usr/sbin/util" ]; then
    mkdir /usr/sbin/util
fi
install -m 0755 -o root -g root $UPD825/usr/sbin/util/chkpw /usr/sbin/util
install -m 0755 -o root -g root $UPD825/usr/sbin/util/genrdpkeys /usr/sbin/util
install -m 0755 -o root -g root $UPD825/usr/sbin/util/hash825 /usr/sbin/util
install -m 0755 -o root -g root $UPD825/usr/sbin/util/iptblsave /usr/sbin/util
install -m 0755 -o root -g root $UPD825/usr/sbin/util/mnbdcomm /usr/sbin/util
install -m 0755 -o root -g root $UPD825/usr/sbin/util/pwchg /usr/sbin/util
install -m 0755 -o root -g root $UPD825/usr_sbin_util/setfan_enable /usr/sbin/util
install -m 0755 -o root -g root $UPD825/usr_sbin_util/setlcd_enable /usr/sbin/util
install -m 0755 -o root -g root $UPD825/usr/sbin/util/setmute /usr/sbin/util
install -m 0755 -o root -g root $UPD825/usr/sbin/util/setremfirmware /usr/sbin/util
install -m 0755 -o root -g root $UPD825/usr/sbin/util/setremstate /usr/sbin/util
install -m 0755 -o root -g root $UPD825/usr/sbin/util/setsnso /usr/sbin/util
install -m 0755 -o root -g root $UPD825/usr_sbin_util/setusbc_enable /usr/sbin/util
install -m 0755 -o root -g root $UPD825/usr/sbin/util/test825 /usr/sbin/util
install -m 0755 -o root -g root $UPD825/usr/sbin/util/test825nostop /usr/sbin/util
install -m 0755 -o root -g root $UPD825/usr/sbin/util/createdb /usr/sbin/util
install -m 0755 -o root -g root $UPD825/usr/sbin/util/createdbuser /usr/sbin/util
install -m 0755 -o root -g root $UPD825/usr/sbin/util/deldbuser /usr/sbin/util
install -m 0755 -o root -g root $UPD825/usr/sbin/util/listdbusers /usr/sbin/util
install -m 0755 -o root -g root $UPD825/usr/sbin/util/enablemysql /usr/sbin/util
install -m 0755 -o root -g root $UPD825/usr/sbin/util/disablemysql /usr/sbin/util
install -m 0755 -o root -g root $UPD825/usr/sbin/util/mscale.sh /usr/sbin/util
install -m 0755 -o root -g root $UPD825/usr/sbin/util/appdirmod /usr/sbin/util
install -m 0755 -o root -g root $UPD825/usr/sbin/util/setuserportmin /usr/sbin/util

if [ -f "/usr/bin/iptblsave" ]; then
    rm /usr/bin/iptblsave
fi
if [ -f "/usr/bin/mnbdcomm" ]; then
    rm /usr/bin/mnbdcomm
fi
if [ -f "/usr/bin/pwchg" ]; then
    rm /usr/bin/pwchg
fi
if [ -f "/usr/bin/setfan_enable" ]; then
    rm /usr/bin/setfan_enable
fi
if [ -f "/usr/bin/setlcd_enable" ]; then
    rm /usr/bin/setlcd_enable
fi
if [ -f "/usr/bin/setmute" ]; then
    rm /usr/bin/setmute
fi
if [ -f "/usr/bin/setremfirmware" ]; then
    rm /usr/bin/setremfirmware
fi
if [ -f "/usr/bin/setremstate" ]; then
    rm /usr/bin/setremstate
fi
if [ -f "/usr/bin/setsnso" ]; then
    rm /usr/bin/setsnso
fi
if [ -f "/usr/bin/setusbc_enable" ]; then
    rm /usr/bin/setusbc_enable
fi
if [ -f "/usr/bin/test825" ]; then
    rm /usr/bin/test825
fi
if [ -f "/usr/bin/test825nostop" ]; then
    rm /usr/bin/test825nostop
fi

cp -p -f $UPD825/etc/profile.d/setenv825.sh /etc/profile.d

install -m 0644 -o root -g root -p $UPD825/etc/sudoers.d/admin /etc/sudoers.d
install -m 0644 -o root -g root -p $UPD825/etc/sudoers.d/www-data /etc/sudoers.d
install -m 0644 -o root -g root -p $UPD825/etc/sudoers.d/sudopath /etc/sudoers.d

cp -p -f $UPD825/etc/apache2/httpd.conf /etc/apache2


#cp -p -f $UPD825/usr/images/icon_app_btn5.bmp /usr/images
#cp -p -f $UPD825/usr/images/icon_app_btn7.bmp /usr/images
#cp -p -f $UPD825/usr/images/icon_app_btn10.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/cardinal330x82.png /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/825g2_375x208dk.png /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_btn_1chk3dk.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_btn_1chk5dk.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_btn_1chk7dk.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_btn_1chk10dk.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_btn_2chk3dk.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_btn_2chk5dk.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_btn_2chk7dk.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_btn_2chk10dk.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_btn_menu3.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_btn_menu5.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_btn_menu7.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_btn_menu10.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/cardlogobw280x72.bmp /usr/images

install -m 0644 -o root -g root -p $UPD825/usr/images/icon_truck_id_storagedk.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_checkweighdk.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_dfcdk.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_hwsdk.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_multiscaledk.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_filemgrdk.bmp /usr/images

install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_vrs.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_vrsdk.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_cbw.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_cbwdk.bmp /usr/images

install -m 0644 -o root -g root -p $UPD825/usr/images/icon_hand10dk.bmp /usr/images

install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_btn_units3.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_btn_units5.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_btn_units7.bmp /usr/images
install -m 0644 -o root -g root -p $UPD825/usr/images/icon_app_btn_units10.bmp /usr/images

install -m 0755 -o root -g root -p $UPD825/diag/game/ast.html /usr/sbin/diag/game
install -m 0755 -o root -g root -p $UPD825/diag/game/ast.js /usr/sbin/diag/game
install -m 0755 -o root -g root -p $UPD825/diag/game/ast.css /usr/sbin/diag/game
install -m 0755 -o root -g root -p $UPD825/diag/game/LICENSE.txt /usr/sbin/diag/game

install -m 0644 -o root -g root -p $UPD825/firmware/mnbd825.elf /lib/firmware
install -m 0644 -o root -g root -p $UPD825/modules/cardmnbdm.ko /lib/modules/5.15.60*/extra

install -m 0644 -o root -g root -p $UPD825/usr/lib/libwebsockets.so.18 /usr/lib
install -m 0644 -o root -g root -p $UPD825/usr/lib/libwebsockets-evlib_uv.so /usr/lib

if [ ! -d "/usr" ]; then
  install -d -m 755 -o root -g root /usr
fi
if [ ! -d "/usr/bin" ]; then
  install -d -m 755 -o root -g root /usr/bin
fi
install -m 755 -o root -g root $UPD825/apache2/usr/bin/htdbm /usr/bin/htdbm
install -m 755 -o root -g root $UPD825/apache2/usr/bin/htdigest /usr/bin/htdigest
install -m 755 -o root -g root $UPD825/apache2/usr/bin/logresolve /usr/bin/logresolve
install -m 755 -o root -g root $UPD825/apache2/usr/bin/httxt2dbm /usr/bin/httxt2dbm
install -m 755 -o root -g root $UPD825/apache2/usr/bin/htpasswd /usr/bin/htpasswd
install -m 755 -o root -g root $UPD825/apache2/usr/bin/dbmmanage /usr/bin/dbmmanage
install -m 755 -o root -g root $UPD825/apache2/usr/bin/apxs /usr/bin/apxs
install -m 755 -o root -g root $UPD825/apache2/usr/bin/ab /usr/bin/ab
if [ ! -d "/usr/include" ]; then
  install -d -m 755 -o root -g root /usr/include
fi
if [ ! -d "/usr/include/apache2" ]; then
  install -d -m 755 -o root -g root /usr/include/apache2
fi
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/ap_config_auto.h /usr/include/apache2/ap_config_auto.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/util_fcgi.h /usr/include/apache2/util_fcgi.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/util_md5.h /usr/include/apache2/util_md5.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/scoreboard.h /usr/include/apache2/scoreboard.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/http_core.h /usr/include/apache2/http_core.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/http_main.h /usr/include/apache2/http_main.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/mod_session.h /usr/include/apache2/mod_session.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/util_ebcdic.h /usr/include/apache2/util_ebcdic.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/mod_cgi.h /usr/include/apache2/mod_cgi.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/mpm_common.h /usr/include/apache2/mpm_common.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/mod_status.h /usr/include/apache2/mod_status.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/mod_dav.h /usr/include/apache2/mod_dav.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/mod_auth.h /usr/include/apache2/mod_auth.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/mod_log_config.h /usr/include/apache2/mod_log_config.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/util_time.h /usr/include/apache2/util_time.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/http_protocol.h /usr/include/apache2/http_protocol.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/httpd.h /usr/include/apache2/httpd.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/apache_noprobes.h /usr/include/apache2/apache_noprobes.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/mod_ssl.h /usr/include/apache2/mod_ssl.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/util_cfgtree.h /usr/include/apache2/util_cfgtree.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/http_ssl.h /usr/include/apache2/http_ssl.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/mod_core.h /usr/include/apache2/mod_core.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/ap_expr.h /usr/include/apache2/ap_expr.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/mod_include.h /usr/include/apache2/mod_include.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/ap_regex.h /usr/include/apache2/ap_regex.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/util_script.h /usr/include/apache2/util_script.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/ap_listen.h /usr/include/apache2/ap_listen.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/http_log.h /usr/include/apache2/http_log.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/util_charset.h /usr/include/apache2/util_charset.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/ap_mmn.h /usr/include/apache2/ap_mmn.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/http_config.h /usr/include/apache2/http_config.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/unixd.h /usr/include/apache2/unixd.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/mod_dbd.h /usr/include/apache2/mod_dbd.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/ap_release.h /usr/include/apache2/ap_release.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/mod_cache.h /usr/include/apache2/mod_cache.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/mod_request.h /usr/include/apache2/mod_request.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/ap_compat.h /usr/include/apache2/ap_compat.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/http_request.h /usr/include/apache2/http_request.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/ap_socache.h /usr/include/apache2/ap_socache.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/http_vhost.h /usr/include/apache2/http_vhost.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/ap_config.h /usr/include/apache2/ap_config.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/mod_unixd.h /usr/include/apache2/mod_unixd.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/cache_common.h /usr/include/apache2/cache_common.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/util_xml.h /usr/include/apache2/util_xml.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/mod_rewrite.h /usr/include/apache2/mod_rewrite.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/http_connection.h /usr/include/apache2/http_connection.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/util_filter.h /usr/include/apache2/util_filter.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/os.h /usr/include/apache2/os.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/ap_slotmem.h /usr/include/apache2/ap_slotmem.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/ap_config_layout.h /usr/include/apache2/ap_config_layout.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/heartbeat.h /usr/include/apache2/heartbeat.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/util_mutex.h /usr/include/apache2/util_mutex.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/ap_hooks.h /usr/include/apache2/ap_hooks.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/util_cookies.h /usr/include/apache2/util_cookies.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/ap_mpm.h /usr/include/apache2/ap_mpm.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/ap_provider.h /usr/include/apache2/ap_provider.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/mod_so.h /usr/include/apache2/mod_so.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/ap_regkey.h /usr/include/apache2/ap_regkey.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/util_varbuf.h /usr/include/apache2/util_varbuf.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/mod_xml2enc.h /usr/include/apache2/mod_xml2enc.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/mod_proxy.h /usr/include/apache2/mod_proxy.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/mod_ssl_openssl.h /usr/include/apache2/mod_ssl_openssl.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/mod_http2.h /usr/include/apache2/mod_http2.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/util_ldap.h /usr/include/apache2/util_ldap.h
install -m 644 -o root -g root $UPD825/apache2/usr/include/apache2/mod_watchdog.h /usr/include/apache2/mod_watchdog.h
if [ ! -d "/usr/libexec" ]; then
  install -d -m 755 -o root -g root /usr/libexec
fi
if [ ! -d "/usr/libexec/apache2" ]; then
  install -d -m 755 -o root -g root /usr/libexec/apache2
fi
if [ ! -d "/usr/libexec/apache2/modules" ]; then
  install -d -m 755 -o root -g root /usr/libexec/apache2/modules
fi
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_cgid.so /usr/libexec/apache2/modules/mod_cgid.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_userdir.so /usr/libexec/apache2/modules/mod_userdir.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_logio.so /usr/libexec/apache2/modules/mod_logio.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_proxy_http.so /usr/libexec/apache2/modules/mod_proxy_http.so
install -m 644 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/httpd.exp /usr/libexec/apache2/modules/httpd.exp
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_socache_shmcb.so /usr/libexec/apache2/modules/mod_socache_shmcb.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_authz_core.so /usr/libexec/apache2/modules/mod_authz_core.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_proxy_ajp.so /usr/libexec/apache2/modules/mod_proxy_ajp.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_macro.so /usr/libexec/apache2/modules/mod_macro.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_proxy_scgi.so /usr/libexec/apache2/modules/mod_proxy_scgi.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_authz_host.so /usr/libexec/apache2/modules/mod_authz_host.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_dumpio.so /usr/libexec/apache2/modules/mod_dumpio.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_proxy_express.so /usr/libexec/apache2/modules/mod_proxy_express.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_authz_groupfile.so /usr/libexec/apache2/modules/mod_authz_groupfile.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_alias.so /usr/libexec/apache2/modules/mod_alias.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_auth_form.so /usr/libexec/apache2/modules/mod_auth_form.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_dbd.so /usr/libexec/apache2/modules/mod_dbd.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_session.so /usr/libexec/apache2/modules/mod_session.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_ext_filter.so /usr/libexec/apache2/modules/mod_ext_filter.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_mime.so /usr/libexec/apache2/modules/mod_mime.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_autoindex.so /usr/libexec/apache2/modules/mod_autoindex.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_authn_file.so /usr/libexec/apache2/modules/mod_authn_file.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_lbmethod_heartbeat.so /usr/libexec/apache2/modules/mod_lbmethod_heartbeat.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_dir.so /usr/libexec/apache2/modules/mod_dir.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_lbmethod_byrequests.so /usr/libexec/apache2/modules/mod_lbmethod_byrequests.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_request.so /usr/libexec/apache2/modules/mod_request.so
if [ ! -d "/usr/libexec/apache2/modules/cgi-bin" ]; then
  install -d -m 755 -o root -g root /usr/libexec/apache2/modules/cgi-bin
fi
install -m 644 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/cgi-bin/printenv.vbs /usr/libexec/apache2/modules/cgi-bin/printenv.vbs
install -m 644 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/cgi-bin/printenv /usr/libexec/apache2/modules/cgi-bin/printenv
install -m 644 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/cgi-bin/printenv.wsf /usr/libexec/apache2/modules/cgi-bin/printenv.wsf
install -m 644 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/cgi-bin/test-cgi /usr/libexec/apache2/modules/cgi-bin/test-cgi
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_unique_id.so /usr/libexec/apache2/modules/mod_unique_id.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_proxy_balancer.so /usr/libexec/apache2/modules/mod_proxy_balancer.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_log_debug.so /usr/libexec/apache2/modules/mod_log_debug.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_lbmethod_bybusyness.so /usr/libexec/apache2/modules/mod_lbmethod_bybusyness.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_filter.so /usr/libexec/apache2/modules/mod_filter.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_proxy_uwsgi.so /usr/libexec/apache2/modules/mod_proxy_uwsgi.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_status.so /usr/libexec/apache2/modules/mod_status.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_authn_anon.so /usr/libexec/apache2/modules/mod_authn_anon.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_socache_redis.so /usr/libexec/apache2/modules/mod_socache_redis.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_sed.so /usr/libexec/apache2/modules/mod_sed.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_buffer.so /usr/libexec/apache2/modules/mod_buffer.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_session_crypto.so /usr/libexec/apache2/modules/mod_session_crypto.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_socache_memcache.so /usr/libexec/apache2/modules/mod_socache_memcache.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_include.so /usr/libexec/apache2/modules/mod_include.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_proxy.so /usr/libexec/apache2/modules/mod_proxy.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_deflate.so /usr/libexec/apache2/modules/mod_deflate.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_rewrite.so /usr/libexec/apache2/modules/mod_rewrite.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_actions.so /usr/libexec/apache2/modules/mod_actions.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_lbmethod_bytraffic.so /usr/libexec/apache2/modules/mod_lbmethod_bytraffic.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_reqtimeout.so /usr/libexec/apache2/modules/mod_reqtimeout.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_socache_dbm.so /usr/libexec/apache2/modules/mod_socache_dbm.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_expires.so /usr/libexec/apache2/modules/mod_expires.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_proxy_hcheck.so /usr/libexec/apache2/modules/mod_proxy_hcheck.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_cache_disk.so /usr/libexec/apache2/modules/mod_cache_disk.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_slotmem_shm.so /usr/libexec/apache2/modules/mod_slotmem_shm.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_ratelimit.so /usr/libexec/apache2/modules/mod_ratelimit.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_remoteip.so /usr/libexec/apache2/modules/mod_remoteip.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_authn_dbm.so /usr/libexec/apache2/modules/mod_authn_dbm.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_session_cookie.so /usr/libexec/apache2/modules/mod_session_cookie.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_authn_core.so /usr/libexec/apache2/modules/mod_authn_core.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_authz_dbd.so /usr/libexec/apache2/modules/mod_authz_dbd.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_speling.so /usr/libexec/apache2/modules/mod_speling.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_proxy_connect.so /usr/libexec/apache2/modules/mod_proxy_connect.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_authz_owner.so /usr/libexec/apache2/modules/mod_authz_owner.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_proxy_fcgi.so /usr/libexec/apache2/modules/mod_proxy_fcgi.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_unixd.so /usr/libexec/apache2/modules/mod_unixd.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_auth_basic.so /usr/libexec/apache2/modules/mod_auth_basic.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_proxy_fdpass.so /usr/libexec/apache2/modules/mod_proxy_fdpass.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_allowmethods.so /usr/libexec/apache2/modules/mod_allowmethods.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_authn_dbd.so /usr/libexec/apache2/modules/mod_authn_dbd.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_substitute.so /usr/libexec/apache2/modules/mod_substitute.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_access_compat.so /usr/libexec/apache2/modules/mod_access_compat.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_cache_socache.so /usr/libexec/apache2/modules/mod_cache_socache.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_log_config.so /usr/libexec/apache2/modules/mod_log_config.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_authz_dbm.so /usr/libexec/apache2/modules/mod_authz_dbm.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_setenvif.so /usr/libexec/apache2/modules/mod_setenvif.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_authz_user.so /usr/libexec/apache2/modules/mod_authz_user.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_dav_fs.so /usr/libexec/apache2/modules/mod_dav_fs.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_authn_socache.so /usr/libexec/apache2/modules/mod_authn_socache.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_watchdog.so /usr/libexec/apache2/modules/mod_watchdog.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_ssl.so /usr/libexec/apache2/modules/mod_ssl.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_info.so /usr/libexec/apache2/modules/mod_info.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_file_cache.so /usr/libexec/apache2/modules/mod_file_cache.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_proxy_wstunnel.so /usr/libexec/apache2/modules/mod_proxy_wstunnel.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_vhost_alias.so /usr/libexec/apache2/modules/mod_vhost_alias.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_headers.so /usr/libexec/apache2/modules/mod_headers.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_session_dbd.so /usr/libexec/apache2/modules/mod_session_dbd.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_negotiation.so /usr/libexec/apache2/modules/mod_negotiation.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_version.so /usr/libexec/apache2/modules/mod_version.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_cache.so /usr/libexec/apache2/modules/mod_cache.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_env.so /usr/libexec/apache2/modules/mod_env.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_dav.so /usr/libexec/apache2/modules/mod_dav.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_mpm_worker.so /usr/libexec/apache2/modules/mod_mpm_worker.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_proxy_ftp.so /usr/libexec/apache2/modules/mod_proxy_ftp.so
install -m 755 -o root -g root $UPD825/apache2/usr/libexec/apache2/modules/mod_auth_digest.so /usr/libexec/apache2/modules/mod_auth_digest.so
if [ ! -d "/usr/sbin" ]; then
  install -d -m 755 -o root -g root /usr/sbin
fi
install -m 755 -o root -g root $UPD825/apache2/usr/sbin/checkgid /usr/sbin/checkgid
install -m 755 -o root -g root $UPD825/apache2/usr/sbin/httpd /usr/sbin/httpd
install -m 755 -o root -g root $UPD825/apache2/usr/sbin/rotatelogs /usr/sbin/rotatelogs
install -m 755 -o root -g root $UPD825/apache2/usr/sbin/htcacheclean /usr/sbin/htcacheclean
install -m 755 -o root -g root $UPD825/apache2/usr/sbin/fcgistarter /usr/sbin/fcgistarter
install -m 755 -o root -g root $UPD825/apache2/usr/sbin/apachectl /usr/sbin/apachectl
if [ ! -d "/usr/share" ]; then
  install -d -m 755 -o root -g root /usr/share
fi
if [ ! -d "/usr/share/man" ]; then
  install -d -m 755 -o root -g root /usr/share/man
fi
if [ ! -d "/usr/share/man/man8" ]; then
  install -d -m 755 -o root -g root /usr/share/man/man8
fi
install -m 644 -o root -g root $UPD825/apache2/usr/share/man/man8/suexec.8 /usr/share/man/man8/suexec.8
install -m 644 -o root -g root $UPD825/apache2/usr/share/man/man8/apachectl.8 /usr/share/man/man8/apachectl.8
install -m 644 -o root -g root $UPD825/apache2/usr/share/man/man8/httpd.8 /usr/share/man/man8/httpd.8
install -m 644 -o root -g root $UPD825/apache2/usr/share/man/man8/htcacheclean.8 /usr/share/man/man8/htcacheclean.8
install -m 644 -o root -g root $UPD825/apache2/usr/share/man/man8/fcgistarter.8 /usr/share/man/man8/fcgistarter.8
install -m 664 -o root -g root $UPD825/apache2/usr/share/man/man8/rotatelogs.8 /usr/share/man/man8/rotatelogs.8
if [ ! -d "/usr/share/man/man1" ]; then
  install -d -m 755 -o root -g root /usr/share/man/man1
fi
install -m 644 -o root -g root $UPD825/apache2/usr/share/man/man1/htpasswd.1 /usr/share/man/man1/htpasswd.1
install -m 644 -o root -g root $UPD825/apache2/usr/share/man/man1/logresolve.1 /usr/share/man/man1/logresolve.1
install -m 644 -o root -g root $UPD825/apache2/usr/share/man/man1/ab.1 /usr/share/man/man1/ab.1
install -m 644 -o root -g root $UPD825/apache2/usr/share/man/man1/dbmmanage.1 /usr/share/man/man1/dbmmanage.1
install -m 644 -o root -g root $UPD825/apache2/usr/share/man/man1/htdbm.1 /usr/share/man/man1/htdbm.1
install -m 644 -o root -g root $UPD825/apache2/usr/share/man/man1/htdigest.1 /usr/share/man/man1/htdigest.1
install -m 644 -o root -g root $UPD825/apache2/usr/share/man/man1/httxt2dbm.1 /usr/share/man/man1/httxt2dbm.1
install -m 644 -o root -g root $UPD825/apache2/usr/share/man/man1/apxs.1 /usr/share/man/man1/apxs.1
if [ ! -d "/usr/share/apache2" ]; then
  install -d -m 755 -o root -g root /usr/share/apache2
fi
if [ ! -d "/usr/share/apache2/icons" ]; then
  install -d -m 755 -o root -g root /usr/share/apache2/icons
fi
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/alert.red.png /usr/share/apache2/icons/alert.red.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/generic.png /usr/share/apache2/icons/generic.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/odf6otc.png /usr/share/apache2/icons/odf6otc.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/sphere2.gif /usr/share/apache2/icons/sphere2.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/screw1.gif /usr/share/apache2/icons/screw1.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/pie6.gif /usr/share/apache2/icons/pie6.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/comp.gray.gif /usr/share/apache2/icons/comp.gray.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/world1.gif /usr/share/apache2/icons/world1.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/comp.blue.png /usr/share/apache2/icons/comp.blue.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/pie0.gif /usr/share/apache2/icons/pie0.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/dir.gif /usr/share/apache2/icons/dir.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/alert.red.gif /usr/share/apache2/icons/alert.red.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/burst.gif /usr/share/apache2/icons/burst.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/generic.gif /usr/share/apache2/icons/generic.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/screw2.png /usr/share/apache2/icons/screw2.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/burst.png /usr/share/apache2/icons/burst.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/generic.sec.png /usr/share/apache2/icons/generic.sec.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/broken.gif /usr/share/apache2/icons/broken.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/quill.png /usr/share/apache2/icons/quill.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/ps.gif /usr/share/apache2/icons/ps.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/ball.red.png /usr/share/apache2/icons/ball.red.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/pie1.gif /usr/share/apache2/icons/pie1.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/icon.sheet.gif /usr/share/apache2/icons/icon.sheet.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/generic.red.gif /usr/share/apache2/icons/generic.red.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/transfer.png /usr/share/apache2/icons/transfer.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/hand.right.gif /usr/share/apache2/icons/hand.right.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/box2.gif /usr/share/apache2/icons/box2.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/pie7.png /usr/share/apache2/icons/pie7.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/c.gif /usr/share/apache2/icons/c.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/generic.sec.gif /usr/share/apache2/icons/generic.sec.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/image3.gif /usr/share/apache2/icons/image3.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/binhex.gif /usr/share/apache2/icons/binhex.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/forward.png /usr/share/apache2/icons/forward.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/pie8.gif /usr/share/apache2/icons/pie8.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/a.png /usr/share/apache2/icons/a.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/p.gif /usr/share/apache2/icons/p.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/apache_pb.gif /usr/share/apache2/icons/apache_pb.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/pdf.png /usr/share/apache2/icons/pdf.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/odf6odb.png /usr/share/apache2/icons/odf6odb.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/movie.png /usr/share/apache2/icons/movie.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/odf6ods.png /usr/share/apache2/icons/odf6ods.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/uu.gif /usr/share/apache2/icons/uu.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/folder.open.png /usr/share/apache2/icons/folder.open.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/link.png /usr/share/apache2/icons/link.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/apache_pb2.gif /usr/share/apache2/icons/apache_pb2.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/up.gif /usr/share/apache2/icons/up.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/right.gif /usr/share/apache2/icons/right.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/blank.png /usr/share/apache2/icons/blank.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/xml.png /usr/share/apache2/icons/xml.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/pie2.gif /usr/share/apache2/icons/pie2.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/up.png /usr/share/apache2/icons/up.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/screw2.gif /usr/share/apache2/icons/screw2.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/f.png /usr/share/apache2/icons/f.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/portal.png /usr/share/apache2/icons/portal.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/odf6odt.png /usr/share/apache2/icons/odf6odt.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/folder.png /usr/share/apache2/icons/folder.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/README.html /usr/share/apache2/icons/README.html
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/binary.png /usr/share/apache2/icons/binary.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/world1.png /usr/share/apache2/icons/world1.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/down.png /usr/share/apache2/icons/down.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/sound1.gif /usr/share/apache2/icons/sound1.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/README /usr/share/apache2/icons/README
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/image2.gif /usr/share/apache2/icons/image2.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/movie.gif /usr/share/apache2/icons/movie.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/p.png /usr/share/apache2/icons/p.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/odf6odi.png /usr/share/apache2/icons/odf6odi.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/transfer.gif /usr/share/apache2/icons/transfer.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/ball.gray.png /usr/share/apache2/icons/ball.gray.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/ball.red.gif /usr/share/apache2/icons/ball.red.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/index.png /usr/share/apache2/icons/index.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/image1.gif /usr/share/apache2/icons/image1.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/odf6ots.png /usr/share/apache2/icons/odf6ots.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/hand.right.png /usr/share/apache2/icons/hand.right.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/apache_pb.png /usr/share/apache2/icons/apache_pb.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/patch.gif /usr/share/apache2/icons/patch.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/pie5.png /usr/share/apache2/icons/pie5.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/unknown.png /usr/share/apache2/icons/unknown.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/sound2.png /usr/share/apache2/icons/sound2.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/odf6otp.png /usr/share/apache2/icons/odf6otp.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/patch.png /usr/share/apache2/icons/patch.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/image2.png /usr/share/apache2/icons/image2.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/link.gif /usr/share/apache2/icons/link.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/odf6otg.png /usr/share/apache2/icons/odf6otg.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/pie6.png /usr/share/apache2/icons/pie6.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/apache_pb2.png /usr/share/apache2/icons/apache_pb2.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/left.gif /usr/share/apache2/icons/left.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/unknown.gif /usr/share/apache2/icons/unknown.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/odf6oth.png /usr/share/apache2/icons/odf6oth.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/index.gif /usr/share/apache2/icons/index.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/odf6odf.png /usr/share/apache2/icons/odf6odf.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/pie0.png /usr/share/apache2/icons/pie0.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/comp.gray.png /usr/share/apache2/icons/comp.gray.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/folder.sec.gif /usr/share/apache2/icons/folder.sec.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/text.png /usr/share/apache2/icons/text.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/compressed.gif /usr/share/apache2/icons/compressed.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/odf6odp.png /usr/share/apache2/icons/odf6odp.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/box1.png /usr/share/apache2/icons/box1.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/binhex.png /usr/share/apache2/icons/binhex.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/tex.png /usr/share/apache2/icons/tex.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/pie7.gif /usr/share/apache2/icons/pie7.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/tar.gif /usr/share/apache2/icons/tar.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/hand.up.gif /usr/share/apache2/icons/hand.up.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/world2.gif /usr/share/apache2/icons/world2.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/svg.png /usr/share/apache2/icons/svg.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/bomb.png /usr/share/apache2/icons/bomb.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/pie3.png /usr/share/apache2/icons/pie3.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/compressed.png /usr/share/apache2/icons/compressed.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/back.gif /usr/share/apache2/icons/back.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/blank.gif /usr/share/apache2/icons/blank.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/pie4.gif /usr/share/apache2/icons/pie4.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/dvi.png /usr/share/apache2/icons/dvi.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/diskimg.gif /usr/share/apache2/icons/diskimg.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/right.png /usr/share/apache2/icons/right.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/sound2.gif /usr/share/apache2/icons/sound2.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/odf6otf.png /usr/share/apache2/icons/odf6otf.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/continued.png /usr/share/apache2/icons/continued.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/portal.gif /usr/share/apache2/icons/portal.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/bomb.gif /usr/share/apache2/icons/bomb.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/text.gif /usr/share/apache2/icons/text.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/left.png /usr/share/apache2/icons/left.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/dvi.gif /usr/share/apache2/icons/dvi.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/odf6odg.png /usr/share/apache2/icons/odf6odg.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/screw1.png /usr/share/apache2/icons/screw1.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/pie5.gif /usr/share/apache2/icons/pie5.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/f.gif /usr/share/apache2/icons/f.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/pie4.png /usr/share/apache2/icons/pie4.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/box1.gif /usr/share/apache2/icons/box1.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/sphere1.png /usr/share/apache2/icons/sphere1.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/a.gif /usr/share/apache2/icons/a.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/pie1.png /usr/share/apache2/icons/pie1.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/folder.sec.png /usr/share/apache2/icons/folder.sec.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/ball.gray.gif /usr/share/apache2/icons/ball.gray.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/script.png /usr/share/apache2/icons/script.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/broken.png /usr/share/apache2/icons/broken.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/alert.black.gif /usr/share/apache2/icons/alert.black.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/generic.red.png /usr/share/apache2/icons/generic.red.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/ps.png /usr/share/apache2/icons/ps.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/continued.gif /usr/share/apache2/icons/continued.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/back.png /usr/share/apache2/icons/back.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/hand.up.png /usr/share/apache2/icons/hand.up.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/pie2.png /usr/share/apache2/icons/pie2.png
if [ ! -d "/usr/share/apache2/icons/small" ]; then
  install -d -m 775 -o root -g root /usr/share/apache2/icons/small
fi
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/doc.png /usr/share/apache2/icons/small/doc.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/generic.png /usr/share/apache2/icons/small/generic.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/comp1.gif /usr/share/apache2/icons/small/comp1.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/image.png /usr/share/apache2/icons/small/image.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/burst.gif /usr/share/apache2/icons/small/burst.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/generic.gif /usr/share/apache2/icons/small/generic.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/doc.gif /usr/share/apache2/icons/small/doc.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/burst.png /usr/share/apache2/icons/small/burst.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/broken.gif /usr/share/apache2/icons/small/broken.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/image.gif /usr/share/apache2/icons/small/image.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/ps.gif /usr/share/apache2/icons/small/ps.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/transfer.png /usr/share/apache2/icons/small/transfer.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/comp2.png /usr/share/apache2/icons/small/comp2.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/binhex.gif /usr/share/apache2/icons/small/binhex.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/generic2.png /usr/share/apache2/icons/small/generic2.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/forward.png /usr/share/apache2/icons/small/forward.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/generic3.png /usr/share/apache2/icons/small/generic3.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/movie.png /usr/share/apache2/icons/small/movie.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/uu.gif /usr/share/apache2/icons/small/uu.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/blank.png /usr/share/apache2/icons/small/blank.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/rainbow.png /usr/share/apache2/icons/small/rainbow.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/generic3.gif /usr/share/apache2/icons/small/generic3.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/folder.png /usr/share/apache2/icons/small/folder.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/binary.png /usr/share/apache2/icons/small/binary.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/image2.gif /usr/share/apache2/icons/small/image2.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/movie.gif /usr/share/apache2/icons/small/movie.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/transfer.gif /usr/share/apache2/icons/small/transfer.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/index.png /usr/share/apache2/icons/small/index.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/sound.gif /usr/share/apache2/icons/small/sound.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/patch.gif /usr/share/apache2/icons/small/patch.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/unknown.png /usr/share/apache2/icons/small/unknown.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/sound2.png /usr/share/apache2/icons/small/sound2.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/patch.png /usr/share/apache2/icons/small/patch.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/image2.png /usr/share/apache2/icons/small/image2.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/comp1.png /usr/share/apache2/icons/small/comp1.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/unknown.gif /usr/share/apache2/icons/small/unknown.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/index.gif /usr/share/apache2/icons/small/index.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/text.png /usr/share/apache2/icons/small/text.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/compressed.gif /usr/share/apache2/icons/small/compressed.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/binhex.png /usr/share/apache2/icons/small/binhex.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/tar.gif /usr/share/apache2/icons/small/tar.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/folder2.gif /usr/share/apache2/icons/small/folder2.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/key.png /usr/share/apache2/icons/small/key.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/compressed.png /usr/share/apache2/icons/small/compressed.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/back.gif /usr/share/apache2/icons/small/back.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/blank.gif /usr/share/apache2/icons/small/blank.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/sound2.gif /usr/share/apache2/icons/small/sound2.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/continued.png /usr/share/apache2/icons/small/continued.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/text.gif /usr/share/apache2/icons/small/text.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/broken.png /usr/share/apache2/icons/small/broken.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/sound.png /usr/share/apache2/icons/small/sound.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/ps.png /usr/share/apache2/icons/small/ps.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/continued.gif /usr/share/apache2/icons/small/continued.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/back.png /usr/share/apache2/icons/small/back.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/uu.png /usr/share/apache2/icons/small/uu.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/key.gif /usr/share/apache2/icons/small/key.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/tar.png /usr/share/apache2/icons/small/tar.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/rainbow.gif /usr/share/apache2/icons/small/rainbow.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/folder.gif /usr/share/apache2/icons/small/folder.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/comp2.gif /usr/share/apache2/icons/small/comp2.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/forward.gif /usr/share/apache2/icons/small/forward.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/binary.gif /usr/share/apache2/icons/small/binary.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/folder2.png /usr/share/apache2/icons/small/folder2.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/small/generic2.gif /usr/share/apache2/icons/small/generic2.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/uu.png /usr/share/apache2/icons/uu.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/quill.gif /usr/share/apache2/icons/quill.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/pdf.gif /usr/share/apache2/icons/pdf.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/comp.blue.gif /usr/share/apache2/icons/comp.blue.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/icon.sheet.png /usr/share/apache2/icons/icon.sheet.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/uuencoded.png /usr/share/apache2/icons/uuencoded.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/alert.black.png /usr/share/apache2/icons/alert.black.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/sound1.png /usr/share/apache2/icons/sound1.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/box2.png /usr/share/apache2/icons/box2.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/odf6odc.png /usr/share/apache2/icons/odf6odc.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/uuencoded.gif /usr/share/apache2/icons/uuencoded.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/c.png /usr/share/apache2/icons/c.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/tar.png /usr/share/apache2/icons/tar.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/layout.gif /usr/share/apache2/icons/layout.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/apache_pb.svg /usr/share/apache2/icons/apache_pb.svg
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/diskimg.png /usr/share/apache2/icons/diskimg.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/world2.png /usr/share/apache2/icons/world2.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/odf6ott.png /usr/share/apache2/icons/odf6ott.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/odf6odm.png /usr/share/apache2/icons/odf6odm.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/folder.gif /usr/share/apache2/icons/folder.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/script.gif /usr/share/apache2/icons/script.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/tex.gif /usr/share/apache2/icons/tex.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/odf6oti.png /usr/share/apache2/icons/odf6oti.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/down.gif /usr/share/apache2/icons/down.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/dir.png /usr/share/apache2/icons/dir.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/sphere1.gif /usr/share/apache2/icons/sphere1.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/pie8.png /usr/share/apache2/icons/pie8.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/image1.png /usr/share/apache2/icons/image1.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/folder.open.gif /usr/share/apache2/icons/folder.open.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/forward.gif /usr/share/apache2/icons/forward.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/image3.png /usr/share/apache2/icons/image3.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/pie3.gif /usr/share/apache2/icons/pie3.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/binary.gif /usr/share/apache2/icons/binary.gif
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/layout.png /usr/share/apache2/icons/layout.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/icons/sphere2.png /usr/share/apache2/icons/sphere2.png
if [ ! -d "/usr/share/apache2/error" ]; then
  install -d -m 755 -o root -g root /usr/share/apache2/error
fi
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/error/HTTP_REQUEST_ENTITY_TOO_LARGE.html.var /usr/share/apache2/error/HTTP_REQUEST_ENTITY_TOO_LARGE.html.var
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/error/HTTP_VARIANT_ALSO_VARIES.html.var /usr/share/apache2/error/HTTP_VARIANT_ALSO_VARIES.html.var
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/error/HTTP_NOT_FOUND.html.var /usr/share/apache2/error/HTTP_NOT_FOUND.html.var
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/error/HTTP_PRECONDITION_FAILED.html.var /usr/share/apache2/error/HTTP_PRECONDITION_FAILED.html.var
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/error/README /usr/share/apache2/error/README
if [ ! -d "/usr/share/apache2/error/include" ]; then
  install -d -m 775 -o root -g root /usr/share/apache2/error/include
fi
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/error/include/bottom.html /usr/share/apache2/error/include/bottom.html
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/error/include/spacer.html /usr/share/apache2/error/include/spacer.html
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/error/include/top.html /usr/share/apache2/error/include/top.html
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/error/HTTP_UNAUTHORIZED.html.var /usr/share/apache2/error/HTTP_UNAUTHORIZED.html.var
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/error/HTTP_UNSUPPORTED_MEDIA_TYPE.html.var /usr/share/apache2/error/HTTP_UNSUPPORTED_MEDIA_TYPE.html.var
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/error/HTTP_REQUEST_TIME_OUT.html.var /usr/share/apache2/error/HTTP_REQUEST_TIME_OUT.html.var
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/error/HTTP_SERVICE_UNAVAILABLE.html.var /usr/share/apache2/error/HTTP_SERVICE_UNAVAILABLE.html.var
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/error/HTTP_METHOD_NOT_ALLOWED.html.var /usr/share/apache2/error/HTTP_METHOD_NOT_ALLOWED.html.var
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/error/HTTP_BAD_REQUEST.html.var /usr/share/apache2/error/HTTP_BAD_REQUEST.html.var
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/error/HTTP_INTERNAL_SERVER_ERROR.html.var /usr/share/apache2/error/HTTP_INTERNAL_SERVER_ERROR.html.var
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/error/HTTP_REQUEST_URI_TOO_LARGE.html.var /usr/share/apache2/error/HTTP_REQUEST_URI_TOO_LARGE.html.var
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/error/contact.html.var /usr/share/apache2/error/contact.html.var
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/error/HTTP_BAD_GATEWAY.html.var /usr/share/apache2/error/HTTP_BAD_GATEWAY.html.var
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/error/HTTP_NOT_IMPLEMENTED.html.var /usr/share/apache2/error/HTTP_NOT_IMPLEMENTED.html.var
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/error/HTTP_LENGTH_REQUIRED.html.var /usr/share/apache2/error/HTTP_LENGTH_REQUIRED.html.var
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/error/HTTP_GONE.html.var /usr/share/apache2/error/HTTP_GONE.html.var
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/error/HTTP_FORBIDDEN.html.var /usr/share/apache2/error/HTTP_FORBIDDEN.html.var
if [ ! -d "/usr/share/apache2/build" ]; then
  install -d -m 755 -o root -g root /usr/share/apache2/build
fi
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/build/config_vars.mk /usr/share/apache2/build/config_vars.mk
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/build/library.mk /usr/share/apache2/build/library.mk
install -m 755 -o root -g root $UPD825/apache2/usr/share/apache2/build/instdso.sh /usr/share/apache2/build/instdso.sh
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/build/program.mk /usr/share/apache2/build/program.mk
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/build/rules.mk /usr/share/apache2/build/rules.mk
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/build/ltlib.mk /usr/share/apache2/build/ltlib.mk
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/build/special.mk /usr/share/apache2/build/special.mk
install -m 755 -o root -g root $UPD825/apache2/usr/share/apache2/build/mkdir.sh /usr/share/apache2/build/mkdir.sh
install -m 755 -o root -g root $UPD825/apache2/usr/share/apache2/build/config.nice /usr/share/apache2/build/config.nice
if [ ! -d "/usr/share/apache2/default-site" ]; then
  install -d -m 755 -o root -g root /usr/share/apache2/default-site
fi
if [ ! -d "/usr/share/apache2/default-site/htdocs" ]; then
  install -d -m 755 -o root -g root /usr/share/apache2/default-site/htdocs
fi
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/bootstrap.min.css /usr/share/apache2/default-site/htdocs/bootstrap.min.css
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/upload.php /usr/share/apache2/default-site/htdocs/upload.php
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/tinyfilemanager.php /usr/share/apache2/default-site/htdocs/tinyfilemanager.php
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/highlight.min.js /usr/share/apache2/default-site/htdocs/highlight.min.js
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/bootstrap.min.js /usr/share/apache2/default-site/htdocs/bootstrap.min.js
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/128.png /usr/share/apache2/default-site/htdocs/128.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/tlog.php /usr/share/apache2/default-site/htdocs/tlog.php
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/remote.php /usr/share/apache2/default-site/htdocs/remote.php
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/diagnostics.php /usr/share/apache2/default-site/htdocs/diagnostics.php
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/825_Banner.jpg /usr/share/apache2/default-site/htdocs/825_Banner.jpg
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/jquery-3.6.1.min.js /usr/share/apache2/default-site/htdocs/jquery-3.6.1.min.js
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/diagupd.php /usr/share/apache2/default-site/htdocs/diagupd.php
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/sweetalert2.all.min.js /usr/share/apache2/default-site/htdocs/sweetalert2.all.min.js
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/download.php /usr/share/apache2/default-site/htdocs/download.php
if [ ! -d "/usr/share/apache2/default-site/htdocs/inc" ]; then
  install -d -m 777 -o root -g root /usr/share/apache2/default-site/htdocs/inc
fi
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/inc/flash.php /usr/share/apache2/default-site/htdocs/inc/flash.php
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/inc/functions.php /usr/share/apache2/default-site/htdocs/inc/functions.php
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/cardinal.css /usr/share/apache2/default-site/htdocs/cardinal.css
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/index.php /usr/share/apache2/default-site/htdocs/index.php
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/admin.php /usr/share/apache2/default-site/htdocs/admin.php
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/main.css /usr/share/apache2/default-site/htdocs/main.css
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/filemgr.css /usr/share/apache2/default-site/htdocs/filemgr.css
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/dropzone.min.js /usr/share/apache2/default-site/htdocs/dropzone.min.js
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/filemgr_mscale.css /usr/share/apache2/default-site/htdocs/filemgr_mscale.css
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/upload_status.html /usr/share/apache2/default-site/htdocs/upload_status.html
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/font-awesome.min.css /usr/share/apache2/default-site/htdocs/font-awesome.min.css
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/upload_status.php /usr/share/apache2/default-site/htdocs/upload_status.php
if [ ! -d "/usr/share/apache2/default-site/htdocs/upload" ]; then
  install -d -m 777 -o root -g root /usr/share/apache2/default-site/htdocs/upload
fi
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/128128.png /usr/share/apache2/default-site/htdocs/128128.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/test.php /usr/share/apache2/default-site/htdocs/test.php
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/Cardinal_logo.png /usr/share/apache2/default-site/htdocs/Cardinal_logo.png
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/bootstrap.bundle.min.js /usr/share/apache2/default-site/htdocs/bootstrap.bundle.min.js
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/login.php /usr/share/apache2/default-site/htdocs/login.php
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/dataTables.min.js /usr/share/apache2/default-site/htdocs/dataTables.min.js
install -m 644 -o root -g root $UPD825/apache2/usr/share/apache2/default-site/htdocs/jquery.dataTables.min.js /usr/share/apache2/default-site/htdocs/jquery.dataTables.min.js
if [ ! -d "/etc" ]; then
  install -d -m 755 -o root -g root /etc
fi
if [ ! -d "/etc/tmpfiles.d" ]; then
  install -d -m 755 -o root -g root /etc/tmpfiles.d
fi
install -m 644 -o root -g root $UPD825/apache2/etc/tmpfiles.d/apache2-volatile.conf /etc/tmpfiles.d/apache2-volatile.conf
if [ ! -d "/etc/apache2" ]; then
  install -d -m 755 -o root -g root /etc/apache2
fi
install -m 644 -o root -g root $UPD825/apache2/etc/apache2/magic /etc/apache2/magic
if [ ! -d "/etc/apache2/conf.d" ]; then
  install -d -m 755 -o root -g root /etc/apache2/conf.d
fi
install -m 666 -o root -g root $UPD825/apache2/etc/apache2/httpd.conf /etc/apache2/httpd.conf
if [ ! -d "/etc/apache2/modules.d" ]; then
  install -d -m 755 -o root -g root /etc/apache2/modules.d
fi
install -m 644 -o root -g root $UPD825/apache2/etc/apache2/mime.types /etc/apache2/mime.types
if [ ! -d "/etc/apache2/extra" ]; then
  install -d -m 755 -o root -g root /etc/apache2/extra
fi
install -m 644 -o root -g root $UPD825/apache2/etc/apache2/extra/httpd-languages.conf /etc/apache2/extra/httpd-languages.conf
install -m 644 -o root -g root $UPD825/apache2/etc/apache2/extra/proxy-html.conf /etc/apache2/extra/proxy-html.conf
install -m 644 -o root -g root $UPD825/apache2/etc/apache2/extra/httpd-manual.conf /etc/apache2/extra/httpd-manual.conf
install -m 644 -o root -g root $UPD825/apache2/etc/apache2/extra/httpd-userdir.conf /etc/apache2/extra/httpd-userdir.conf
install -m 644 -o root -g root $UPD825/apache2/etc/apache2/extra/httpd-vhosts.conf /etc/apache2/extra/httpd-vhosts.conf
install -m 644 -o root -g root $UPD825/apache2/etc/apache2/extra/httpd-dav.conf /etc/apache2/extra/httpd-dav.conf
install -m 644 -o root -g root $UPD825/apache2/etc/apache2/extra/httpd-info.conf /etc/apache2/extra/httpd-info.conf
install -m 644 -o root -g root $UPD825/apache2/etc/apache2/extra/httpd-mpm.conf /etc/apache2/extra/httpd-mpm.conf
install -m 644 -o root -g root $UPD825/apache2/etc/apache2/extra/httpd-multilang-errordoc.conf /etc/apache2/extra/httpd-multilang-errordoc.conf
install -m 644 -o root -g root $UPD825/apache2/etc/apache2/extra/httpd-ssl.conf /etc/apache2/extra/httpd-ssl.conf
install -m 644 -o root -g root $UPD825/apache2/etc/apache2/extra/httpd-autoindex.conf /etc/apache2/extra/httpd-autoindex.conf
install -m 644 -o root -g root $UPD825/apache2/etc/apache2/extra/httpd-default.conf /etc/apache2/extra/httpd-default.conf
if [ ! -d "/lib" ]; then
  install -d -m 755 -o root -g root /lib
fi
if [ ! -d "/lib/systemd" ]; then
  install -d -m 755 -o root -g root /lib/systemd
fi
if [ ! -d "/lib/systemd/system" ]; then
  install -d -m 755 -o root -g root /lib/systemd/system
fi
install -m 644 -o root -g root $UPD825/apache2/lib/systemd/system/apache2.service /lib/systemd/system/apache2.service

install -m 0644 -o root -g root -p $UPD825/usr/share/apache2/default-site/htdocs/index.php /usr/share/apache2/default-site/htdocs
install -m 0644 -o root -g root -p $UPD825/usr/share/apache2/default-site/htdocs/login.php /usr/share/apache2/default-site/htdocs
install -m 0644 -o root -g root -p $UPD825/usr/share/apache2/default-site/htdocs/tinyfilemanager.php /usr/share/apache2/default-site/htdocs
install -m 0644 -o root -g root -p $UPD825/usr/share/apache2/default-site/htdocs/diagnostics.php /usr/share/apache2/default-site/htdocs
install -m 0644 -o root -g root -p $UPD825/usr/share/apache2/default-site/htdocs/admin.php /usr/share/apache2/default-site/htdocs
install -m 0644 -o root -g root -p $UPD825/usr/share/apache2/default-site/htdocs/reports.php /usr/share/apache2/default-site/htdocs

install -m 0644 -o root -g root -p $UPD825/usr/share/apache2/default-site/htdocs/favicon.ico /usr/share/apache2/default-site/htdocs

if [ ! -d "/usr/share/apache2/default-site/htdocs/reports" ]; then
  install -d -m 755 -o root -g root /usr/share/apache2/default-site/htdocs/reports
fi

install -m 0644 -o root -g root -p $UPD825/usr/share/apache2/default-site/htdocs/reports/ids.php /usr/share/apache2/default-site/htdocs/reports
install -m 0644 -o root -g root -p $UPD825/usr/share/apache2/default-site/htdocs/reports/idscsv.php /usr/share/apache2/default-site/htdocs/reports
install -m 0644 -o root -g root -p $UPD825/usr/share/apache2/default-site/htdocs/reports/idsveh.php /usr/share/apache2/default-site/htdocs/reports
install -m 0644 -o root -g root -p $UPD825/usr/share/apache2/default-site/htdocs/reports/idsprod.php /usr/share/apache2/default-site/htdocs/reports
install -m 0644 -o root -g root -p $UPD825/usr/share/apache2/default-site/htdocs/reports/idscust.php /usr/share/apache2/default-site/htdocs/reports
install -m 0644 -o root -g root -p $UPD825/usr/share/apache2/default-site/htdocs/reports/idsjob.php /usr/share/apache2/default-site/htdocs/reports
install -m 0644 -o root -g root -p $UPD825/usr/share/apache2/default-site/htdocs/reports/idstrannum.php /usr/share/apache2/default-site/htdocs/reports
install -m 0644 -o root -g root -p $UPD825/usr/share/apache2/default-site/htdocs/reports/idsprodgraph.php /usr/share/apache2/default-site/htdocs/reports

install -m 0644 -o root -g root -p $UPD825/usr/share/apache2/default-site/htdocs/reports/batcherformulas.php /usr/share/apache2/default-site/htdocs/reports
install -m 0644 -o root -g root -p $UPD825/usr/share/apache2/default-site/htdocs/reports/batcherfrmaccum.php /usr/share/apache2/default-site/htdocs/reports
install -m 0644 -o root -g root -p $UPD825/usr/share/apache2/default-site/htdocs/reports/batcherbinaccum.php /usr/share/apache2/default-site/htdocs/reports

if [ ! -d "/usr/share/apache2/default-site/htdocs/reports/custom" ]; then
  install -d -m 777 -o root -g root /usr/share/apache2/default-site/htdocs/reports/custom
fi

cp -p -f $UPD825/diag/cardver /usr/sbin/diag
cp -p -f $UPD825/diag/pver /usr/sbin/diag

# Set ownership
chown root:root /usr/sbin/diag/*
chown root:root /usr/libexec/cups/filter/rastertostarm

# Delete this file
rm $0

